@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -34,7 +34,7 @@ class SieveEditorMainWidget : public QSplitter
 {
     Q_OBJECT
 public:
-    explicit SieveEditorMainWidget(KActionCollection *ac, QWidget *parent = Q_NULLPTR);
+    explicit SieveEditorMainWidget(KActionCollection *ac, QWidget *parent = nullptr);
     ~SieveEditorMainWidget();
 
     void createNewScript();
@@ -101,7 +101,7 @@ Q_SIGNALS:
     void sieveEditorTabCurrentChanged();
 
 private Q_SLOTS:
-    void slotCreateScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript);
+    void slotCreateScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings);
     void slotScriptDeleted(const QUrl &url);
     void slotScriptRenamed(const QUrl &oldUrl, const QUrl &newUrl);
     void slotScriptModified(bool modified, SieveEditorPageWidget *page);
